==> haskell-logict-0.8.2.0-34-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logict
version:              0.8.2.0
visibility:           public
id:                   logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
key:                  logict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  72a19c24248feedf2e920934adc9c562
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.8.2.0-CD4lQOk6sxu6uUiFGNVpmj
depends:
    base-4.18.2.1 exceptions-0.10.7 mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.8.2.0-36-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logict
version:              0.8.2.0
visibility:           public
id:                   logict-0.8.2.0-CetHJCqKZCxLCYt6b5EYXS
key:                  logict-0.8.2.0-CetHJCqKZCxLCYt6b5EYXS
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  7143affd9568f7c5f39c19fbbddc376e
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/logict-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.8.2.0-CetHJCqKZCxLCYt6b5EYXS
depends:
    base-4.18.2.1 exceptions-0.10.7 mtl-2.3.1 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
